@@ -1,5 +1,5 @@
 package Mojo::Weixin;
-our $VERSION = '1.0.7';
+our $VERSION = '1.0.8';
 use Mojo::Weixin::Base 'Mojo::EventEmitter';
 use Mojo::IOLoop;
 use Mojo::Weixin::Log;
@@ -96,6 +96,11 @@ sub on {
     }
     return wantarray?@return:$return[0];
 }
+sub emit {
+    my $self = shift;
+    $self->SUPER::emit(@_);
+    $self->SUPER::emit(all_event=>@_);
+}
 
 sub wait_once {
     my $self = shift;
