@@ -5,6 +5,7 @@ use List::Util qw(first);
 use Mojo::Weixin::Model::Remote::_webwxinit;
 use Mojo::Weixin::Model::Remote::_webwxgetcontact;
 use Mojo::Weixin::Model::Remote::_webwxbatchgetcontact;
+use Mojo::Weixin::Model::Remote::_webwxstatusnotify;
 use Mojo::Weixin::User;
 use Mojo::Weixin::Group;
 use Mojo::Weixin::Const;
@@ -21,8 +22,8 @@ sub model_init{
     if(defined $user){
         $self->info("更新个人信息成功");
         $self->user(Mojo::Weixin::User->new($user));
+        $self->_webwxstatusnotify(3);
     }
-
     my $contactinfo = $self->_webwxgetcontact();
     if(not defined $contactinfo){
         $self->error("获取通讯录联系人信息失败");
@@ -142,25 +143,25 @@ sub add_friend{
     my $self = shift;
     my $friend = shift;
     $self->die("不支持的数据类型\n") if ref $friend ne "Mojo::Weixin::Friend";
-    return $self->_add($self->friend,$friend);   
+    $self->emit(new_friend=>$friend) if $self->_add($self->friend,$friend) == 1;
 }
 sub remove_friend{
     my $self = shift;
     my $friend = shift;
     $self->die("不支持的数据类型\n") if ref $friend ne "Mojo::Weixin::Friend";
-    return $self->_remove($self->friend,$friend);
+    $self->emit(lose_friend=>$friend) if $self->_remove($self->friend,$friend) == 1;
 }
 sub add_group{
     my $self = shift;
     my $group = shift;
     $self->die("不支持的数据类型\n") if ref $group ne "Mojo::Weixin::Group";
-    return $self->_add($self->group,$group);
+    $self->emit(new_group=>$group) if $self->_add($self->group,$group) == 1;
 }
 sub remove_group{
     my $self = shift;
     my $group = shift;
     $self->die("不支持的数据类型\n") if ref $group ne "Mojo::Weixin::Group";
-    return $self->_remove($self->group,$group);
+    $self->emit(lose_group=>$group) if $self->_remove($self->group,$group) == 1;
 }
 
 sub is_group{
